pub struct ArraySeq<T, const N: usize> { /* private fields */ }Trait Implementations
Sourceimpl<T, const N: usize> Sequence for ArraySeq<T, N>
impl<T, const N: usize> Sequence for ArraySeq<T, N>
type Item = T
type Iter = IntoIter<T, N>
Sourcetype MinSize = StaticSize<<Const<N> as ToUInt>::Output>
type MinSize = StaticSize<<Const<N> as ToUInt>::Output>
The minimum size of the sequence. Read more
Sourcetype MaxSize = StaticSize<<Const<N> as ToUInt>::Output>
type MaxSize = StaticSize<<Const<N> as ToUInt>::Output>
The maximum size of the sequence. Read more
const MIN_SIZE: Option<SizeKind> = <Self::MinSize>::STATIC_SIZE
const MAX_SIZE: Option<SizeKind> = <Self::MaxSize>::STATIC_SIZE
Sourcefn collect_array<const N: usize>(self) -> [Self::Item; N]
fn collect_array<const N: usize>(self) -> [Self::Item; N]
Collects this sequence’s elements into an array.
Sourcefn collect_array_in_place<const N: usize>(
self,
out: &mut MaybeUninit<[Self::Item; N]>,
)
fn collect_array_in_place<const N: usize>( self, out: &mut MaybeUninit<[Self::Item; N]>, )
Collects this sequence’s elements into an array in place.
Sourcefn map<F, B>(self, f: F) -> Map<Self, F>
fn map<F, B>(self, f: F) -> Map<Self, F>
Returns a new sequence that transforms every element of
the original sequence using
f.Sourcefn flat_map<F, U>(self, f: F) -> FlatMap<Self, F>
fn flat_map<F, U>(self, f: F) -> FlatMap<Self, F>
Returns a new sequence that transforms every element of the original
sequence by calling
f and then “flattening” the result.Sourcefn enumerate(self) -> Enumerate<Self>where
Self: Sized,
fn enumerate(self) -> Enumerate<Self>where
Self: Sized,
Returns a new sequence that yields the current iteration index
together with every element.
Sourcefn take_exact_stn<N: Unsigned>(self) -> TakeExactSTn<Self, N>where
Self: Sized,
fn take_exact_stn<N: Unsigned>(self) -> TakeExactSTn<Self, N>where
Self: Sized,
Returns a new sequence that always yields the first exactly
N elements.Sourcefn take_exact_s<const N: usize>(self) -> TakeExactS<Self, N>
fn take_exact_s<const N: usize>(self) -> TakeExactS<Self, N>
Returns a new sequence that always yields the first exactly
N elements.Auto Trait Implementations
impl<T, const N: usize> Freeze for ArraySeq<T, N>where
T: Freeze,
impl<T, const N: usize> RefUnwindSafe for ArraySeq<T, N>where
T: RefUnwindSafe,
impl<T, const N: usize> Send for ArraySeq<T, N>where
T: Send,
impl<T, const N: usize> Sync for ArraySeq<T, N>where
T: Sync,
impl<T, const N: usize> Unpin for ArraySeq<T, N>where
T: Unpin,
impl<T, const N: usize> UnwindSafe for ArraySeq<T, N>where
T: UnwindSafe,