Trait IntoSequence

pub trait IntoSequence {
    type Item;
    type Sequence: Sequence<Item = Self::Item>;

    // Required method
    fn into_sequence(self) -> Self::Sequence;
}
Represents a type that can be converted into a sequence.

The motivation behind this trait is to avoid directly implementing Sequence for builtin types, which could lead to ambiguities for end users because of method name collisions.

Required Associated Types

type Item

type Sequence: Sequence<Item = Self::Item>

Required Methods

fn into_sequence(self) -> Self::Sequence

Converts self into a sequence.

Implementors